==> openGion6.4.0.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF81S.sql <==
/****************************************************************************/
/* GF81 ( ARG変数定義 )                                                     */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF81 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (   1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , OBJ_NAME     VARCHAR2 (  30 )                    NOT NULL            /*  30 ｵﾌﾞｼﾞｪｸﾄ名   */
 , SEQNO        NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  40 表示順       */
 , CLM          VARCHAR2 (  30 )                    NOT NULL            /*  50 項目         */
 , CLS_NAME     VARCHAR2 (  10 )                    NOT NULL            /*  60 DBｸﾗｽ        */
 , USE_LENGTH   VARCHAR2 (   9 )                                        /*  70 使用桁数     */
 , TABLE_NAME   VARCHAR2 (  50 )                                        /*  80 ﾃｰﾌﾞﾙ名      */
 , MAX_LENGTH   VARCHAR2 (  10 )                                        /*  90 最大使用桁数 */
 , CLM_NAME     VARCHAR2 ( 120 )                                        /* 100 項目名(漢字) */
 , CDKH         VARCHAR2 (   1 )                                        /* 180 改廃ｺｰﾄﾞ     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF81S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF81T00 
  BEFORE INSERT ON GF81
  FOR EACH ROW 
  BEGIN 
    SELECT GF81S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.1.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF81S.sql <==
/****************************************************************************/
/* GF81 ( ARG変数定義 )                                                     */
/*                                                                          */
/* Created : 2016/01/07 17:07:19                                            */
/****************************************************************************/
CREATE TABLE GF81 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR2 (   1 )                    NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , OBJ_NAME     VARCHAR2 (  30 )                    NOT NULL            /*  30 ｵﾌﾞｼﾞｪｸﾄ名   */
 , SEQNO        NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  40 表示順       */
 , CLM          VARCHAR2 (  30 )                    NOT NULL            /*  50 項目         */
 , CLS_NAME     VARCHAR2 (  10 )                    NOT NULL            /*  60 DBｸﾗｽ        */
 , USE_LENGTH   VARCHAR2 (   9 )                                        /*  70 使用桁数     */
 , TABLE_NAME   VARCHAR2 (  50 )                                        /*  80 ﾃｰﾌﾞﾙ名      */
 , MAX_LENGTH   VARCHAR2 (  10 )                                        /*  90 最大使用桁数 */
 , CLM_NAME     VARCHAR2 ( 120 )                                        /* 100 項目名(漢字) */
 , CDKH         VARCHAR2 (   1 )                                        /* 180 改廃ｺｰﾄﾞ     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF81S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF81T00 
  BEFORE INSERT ON GF81
  FOR EACH ROW 
  BEGIN 
    SELECT GF81S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
